summaryrefslogtreecommitdiffstats
path: root/doc/src/snippets/code/src_network_kernel_qhostinfo.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'doc/src/snippets/code/src_network_kernel_qhostinfo.cpp')
-rw-r--r--doc/src/snippets/code/src_network_kernel_qhostinfo.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/doc/src/snippets/code/src_network_kernel_qhostinfo.cpp b/doc/src/snippets/code/src_network_kernel_qhostinfo.cpp
index e748f9090..b96a77798 100644
--- a/doc/src/snippets/code/src_network_kernel_qhostinfo.cpp
+++ b/doc/src/snippets/code/src_network_kernel_qhostinfo.cpp
@@ -1,6 +1,6 @@
//! [0]
-// To find the IP address of qtsoftware.com
-QHostInfo::lookupHost("qtsoftware.com",
+// To find the IP address of qt.nokia.com
+QHostInfo::lookupHost("qt.nokia.com",
this, SLOT(printResults(QHostInfo)));
// To find the host name for 4.2.2.1
@@ -10,7 +10,7 @@ QHostInfo::lookupHost("4.2.2.1",
//! [1]
-QHostInfo info = QHostInfo::fromName("qtsoftware.com");
+QHostInfo info = QHostInfo::fromName("qt.nokia.com");
//! [1]